@@ -1,53 +1,22 @@
+from pathlib import Path
 import json
 import re
-import time
-from pathlib import Path
 import sys
 
+from natsort import natsorted
+from rich.table import Table
+from rich.live import Live
 import pandas as pd
 import PySimpleGUI as sg
-from rich.live import Live
-from rich.table import Table
-from watchdog.events import FileSystemEventHandler
-from watchdog.observers import Observer
+from watchfiles import watch, Change, DefaultFilter
 
-
-class Watcher:
-    def __init__(self, directory, handler=FileSystemEventHandler()):
-        self.observer = Observer()
-        self.handler = handler
-        self.directory = directory
-
-    def run(self):
-        self.observer.schedule(
-            self.handler, self.directory, recursive=True)
-        self.observer.start()
-        print(f"\nManuscript Monitor started in {self.directory}\n")
-        try:
-            while True:
-                time.sleep(.2)
-        except:
-            self.observer.stop()
-        self.observer.join()
-        print("\nManuscript Monitor Terminated\n")
-
-class MyHandler(FileSystemEventHandler):
-    def on_created(self, event):
-        created = event.src_path
-        if created.endswith('.iiq'):
-            created = Path(created).name
-            created = re.sub(r'_.+_', '', created).replace('M', '').replace('P', '')
-            created = created.replace('.iiq', '')
-            created = created.lstrip('0')
-            # if created == 'a' or created == 'b':
-            #     created = f'0{created}'
-            ######################
-            ### business logic ###
-            ######################
-            prev, now, next = get_rows(created)
-            global live
-            live.update(generate_table(prev, now, next))
-            ######################
+class CaptureOneFilter(DefaultFilter):
+    allowed_extensions = '.iiq', '.IIQ'
+    def __call__(self, change: Change, path: str) -> bool:
+        return (
+            super().__call__(change, path) and 
+            path.endswith(self.allowed_extensions)
+        )
 
 def generate_table(prev_row: dict, now_row: dict, next_row: dict) -> Table:
     """Make a new table."""
@@ -61,13 +30,15 @@ def generate_table(prev_row: dict, now_row: dict, next_row: dict) -> Table:
     table.add_row(f"{next_row.get('Landmark')}", f"{next_row.get('Actual Folio')}", f"{next_row.get('Notes for Imagers')}")
     return table
 
-def get_rows(just_captured: dict):
+def get_rows(just_captured: dict, guide_dict, version: bool):
     prev = {}
     now = {}
     next = {}
     for i, d in enumerate(guide_dict):
         if f"{d['Image #']}" == just_captured:
-            prev = d
+            prev = d.copy()
+            if version:
+                prev['Landmark'] = f'!{d["Landmark"]}{version}!'
             try:
                 now = guide_dict[i+1]
             except:
@@ -88,9 +59,11 @@ def get_folders():
         settings['excel_folder']
     except:
         settings = {'last_folder': '', 'excel_folder': ''}
+    sg.popup_ok('Select the capture folder for this session', title='Set Capture Folder')
     capture_output = sg.popup_get_folder('', no_window=True, initial_folder=settings['last_folder'])
     if not capture_output:
         sys.exit()
+    sg.popup_ok('Now select the Excel spreadsheet file that has been\ngenerated for this artifact.', title='Select Spreadsheet')
     excel_file = sg.popup_get_file('', no_window=True, initial_folder=settings['excel_folder'], file_types=(('Excel File', '*.xlsx'),))
     if not excel_file:
         sys.exit()
@@ -107,20 +80,26 @@ def get_spreadsheet_data(excel_file):
     list_of_dicts = df.to_dict('records')
     return list_of_dicts
 
-
-capture_output, excel_file = get_folders()
-guide_dict = get_spreadsheet_data(excel_file)
-
-# while True:
-#     answer = input('Digitize in reverse order? (y/n): ')
-#     if answer == 'y' or answer == 'n':
-#         break
-# if answer == 'y':
-#     guide_dict = guide_dict[::-1]
-
-
 def main():
-    global live
-    with Live(generate_table({}, {}, {}), refresh_per_second=5) as live:
-        w = Watcher(capture_output, MyHandler())
-        w.run()    
+    capture_output, excel_file = get_folders()
+    guide_dict = get_spreadsheet_data(excel_file)
+    with Live(generate_table({}, {}, {}), refresh_per_second=10) as live:
+        sg.popup_ok(f'ManuscriptMonitor is watching for new image files in {capture_output}\nTo quit, press CTRL + C or close the terminal.')
+        for changes in watch(capture_output, watch_filter=CaptureOneFilter()):
+            for change, file in natsorted(changes):
+                if change.name == 'added':
+                    created = Path(file).name.replace('.iiq', '')
+                    version = None
+                    for ending in ('_1', '_2', '_3'):
+                        if not created.endswith(ending):
+                            continue
+                        else:
+                            created = created.replace(ending, '')
+                            version = ending
+                            break
+                    created = re.sub(r'_.+_', '', created).replace('M', '').replace('P', '').lstrip('0')
+                    prev, now, next = get_rows(created, guide_dict, version)
+                    live.update(generate_table(prev, now, next))
+
+if __name__ == '__main__':
+    main()
